@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 #### SETUP
 require 'bundler'
 Bundler.setup
@@ -5,7 +6,7 @@ require 'rspec'
 
 require 'support/localhost_server'
 require 'support/server'
-require 'support/memory_test_helpers'
+require_relative 'support/memory_test_helpers'
 
 require 'logger'
 
@@ -33,4 +34,4 @@ if ENV['VERBOSE']
   MemoryTestHelpers.logger.level = Logger::DEBUG
 end
 
-MemoryTestHelpers.iterations = ENV.fetch("ITERATIONS", 10_000).to_i
\ No newline at end of file
+MemoryTestHelpers.iterations = ENV.fetch("ITERATIONS", 10_000).to_i
