@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 require 'spec_helper'
 
 describe Ethon::Easy::Operations do
@@ -25,6 +26,7 @@ describe Ethon::Easy::Operations do
     let(:password) { nil }
 
     before do
+      Ethon.logger.level = Logger::DEBUG
       easy.url = url
       easy.timeout = timeout
       easy.connecttimeout = connect_timeout
@@ -51,7 +53,7 @@ describe Ethon::Easy::Operations do
     end
 
     it "calls Curl.easy_cleanup" do
-      FFI::AutoPointer.any_instance.should_receive(:free)
+      expect_any_instance_of(FFI::AutoPointer).to receive(:free)
       easy.cleanup
     end
 
